# Adapted from EPEL package. EL8, Fedora, Arch, Debian support removed.

# Disable mangling shebangs for dracut module files as it breaks initramfs
%global __brp_mangle_shebangs_exclude_from ^%{_prefix}/lib/dracut/modules.d/.*$

%global desc \
The KIWI Image System provides an operating system image builder \
for Linux supported hardware platforms as well as for virtualization \
and cloud systems like Xen, KVM, VMware, EC2 and more.


Name:           kiwi
Version:        10.2.24
Release:        1%{?dist}
URL:            http://osinside.github.io/kiwi/
Summary:        Flexible operating system image builder
License:        GPL-3.0-or-later
Source0:        https://files.pythonhosted.org/packages/source/k/%{name}/%{name}-%{version}.tar.gz

Patch1001:      0001-Use-buildah-by-default-for-OCI-image-builds.patch
Patch1002:      0001-Add-Rocky-EFI-directory.patch
Patch1003:      0001-Use-isomd5sum-by-default.patch
#Patch1003:      0001-Ensure-BOOT-does-not-contain-erroneous-data.patch

BuildRequires:  bash-completion
BuildRequires:  dracut
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  shadow-utils
# doc build requirements
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)

%description %{desc}


%package systemdeps-core
Summary:        KIWI - Core host system dependencies
Provides:       kiwi-image-tbz-requires = %{version}-%{release}
Obsoletes:      kiwi-image-tbz-requires < %{version}-%{release}
Provides:       kiwi-image:tbz = %{version}-%{release}
Requires:       dnf
%if 0%{?rhel} >= 10
Requires:       dnf5
Provides:       kiwi-packagemanager:dnf5 = %{version}-%{release}
%endif
Provides:       kiwi-packagemanager:dnf = %{version}-%{release}
Provides:       kiwi-packagemanager:dnf4 = %{version}-%{release}
Provides:       kiwi-packagemanager:yum = %{version}-%{release}
%if 0%{?rhel} == 9
Requires:       microdnf
Provides:       kiwi-packagemanager:microdnf = %{version}-%{release}
%endif
# This is part of EPEL.
Recommends:     distribution-gpg-keys
Requires:       lsof
Requires:       mtools
Requires:       rsync
Requires:       sed
Requires:       screen
Requires:       tar >= 1.2.7
Requires:       openssl
Requires:       xz
Obsoletes:      python2-%{name} < %{version}-%{release}
Obsoletes:      %{name}-tools < %{version}-%{release}

%description systemdeps-core
This metapackage installs the necessary system dependencies
to run KIWI.

%ifnarch ppc64 %{ix86}
%package systemdeps-containers
Summary:        KIWI - host requirements for container images
Provides:       kiwi-image:appx
Provides:       kiwi-image:docker
Provides:       kiwi-image:oci
Provides:       kiwi-image:wsl
Provides:       kiwi-image-docker-requires = %{version}-%{release}
Obsoletes:      kiwi-image-docker-requires < %{version}-%{release}
Provides:       kiwi-image-wsl-requires = %{version}-%{release}
Obsoletes:      kiwi-image-wsl-requires < %{version}-%{release}
Requires:       buildah
Requires:       skopeo
Requires:       appx-util

%description systemdeps-containers
Host setup helper to pull in all packages required/useful on
the build host to build container images e.g docker, wsl.
%endif

%package systemdeps-iso-media
Summary:        KIWI - host requirements for live and install iso images
Provides:       kiwi-image:iso = %{version}-%{release}
Provides:       kiwi-image-iso-requires = %{version}-%{release}
Obsoletes:      kiwi-image-iso-requires < %{version}-%{release}
Requires:       xorriso
%ifarch %{ix86} x86_64
# Pull in syslinux when it's x86
%if 0%{?rhel} >= 9
Requires:       syslinux-nonlinux
%endif
Requires:       syslinux
%endif
%ifarch x86_64
Requires:       grub2-efi-x64-cdboot
%endif
%ifarch aarch64
Requires:       grub2-efi-aa64-cdboot
%endif
Requires:       kiwi-systemdeps-core = %{version}-%{release}
Requires:       kiwi-systemdeps-filesystems = %{version}-%{release}
Requires:       kiwi-systemdeps-bootloaders = %{version}-%{release}

%description systemdeps-iso-media
Host setup helper to pull in all packages required/useful on
the build host to build live and install iso images.

%package systemdeps-bootloaders
Summary:        KIWI - host requirements for configuring bootloaders
# the altarch sig provides uboot-tools.
%ifarch aarch64
Recommends:       uboot-tools
Recommends:       rocky-release-altarch
%endif
%ifnarch s390 s390x
# grub isn't available on s390(x) systems
Requires:       grub2-tools
Requires:       grub2-tools-extra
Requires:       grub2-tools-minimal
%endif
%ifarch x86_64
Requires:       grub2-tools-efi
%endif
%ifarch x86_64
Requires:       grub2-efi-x64
Requires:       grub2-efi-x64-modules
%endif
%ifarch %{ix86} x86_64
Requires:       grub2-pc
Requires:       grub2-pc-modules
%endif
%ifarch aarch64
Requires:       grub2-efi-aa64-modules
%endif
%ifarch s390 s390x
Requires:       s390utils
%endif
Requires:       kiwi-systemdeps-core = %{version}-%{release}

%description systemdeps-bootloaders
Host setup helper to pull in all packages required/useful on
the build host for configuring bootloaders on images.

%package systemdeps-filesystems
Summary:        KIWI - host requirements for filesystems
Provides:       kiwi-image:pxe = %{version}-%{release}
Provides:       kiwi-image:kis = %{version}-%{release}
Provides:       kiwi-filesystem:ext2 = %{version}-%{release}
Provides:       kiwi-filesystem:ext3 = %{version}-%{release}
Provides:       kiwi-filesystem:ext4 = %{version}-%{release}
Provides:       kiwi-filesystem:squashfs = %{version}-%{release}
Provides:       kiwi-filesystem:xfs = %{version}-%{release}
Provides:       kiwi-image-pxe-requires = %{version}-%{release}
Obsoletes:      kiwi-image-pxe-requires < %{version}-%{release}
Provides:       kiwi-filesystem-requires = %{version}-%{release}
Obsoletes:      kiwi-filesystem-requires < %{version}-%{release}
Requires:       dosfstools
Requires:       e2fsprogs
Requires:       xfsprogs
Requires:       squashfs-tools
Requires:       qemu-img
Requires:       kiwi-systemdeps-core = %{version}-%{release}

%description systemdeps-filesystems
Host setup helper to pull in all packages required/useful on
the build host to build filesystem images

%package systemdeps-disk-images
Summary:        KIWI - host requirements for disk images
Provides:       kiwi-image:oem = %{version}-%{release}
Provides:       kiwi-image:vmx = %{version}-%{release}
Provides:       kiwi-image-oem-requires = %{version}-%{release}
Obsoletes:      kiwi-image-oem-requires < %{version}-%{release}
Provides:       kiwi-image-vmx-requires = %{version}-%{release}
Obsoletes:      kiwi-image-vmx-requires < %{version}-%{release}
Requires:       kiwi-systemdeps-filesystems = %{version}-%{release}
Requires:       kiwi-systemdeps-bootloaders = %{version}-%{release}
Requires:       kiwi-systemdeps-iso-media = %{version}-%{release}
Requires:       gdisk
Requires:       lvm2
Requires:       parted
Requires:       kpartx
Requires:       cryptsetup
Requires:       mdadm
Requires:       util-linux

%description systemdeps-disk-images
Host setup helper to pull in all packages required/useful on
the build host to build disk images

%package systemdeps-image-validation
Summary:        KIWI - host requirements for handling image descriptions better
%if 0%{?rhel} >= 9
Recommends:     jing
%endif
%if 0%{?rhel} >= 9
Requires:       python3-solv
%endif

%description systemdeps-image-validation
Host setup helper to pull in all packages required/useful on
the build host to handling image descriptions better. This also
includes reading of image descriptions for different markup
languages

%package systemdeps
Summary:        KIWI - Host system dependencies
Requires:       kiwi-systemdeps-core = %{version}-%{release}
Requires:       kiwi-systemdeps-bootloaders = %{version}-%{release}
%ifnarch ppc64 %{ix86}
# buildah isn't available on ppc64 or x86_32
Requires:       kiwi-systemdeps-containers = %{version}-%{release}
%endif
Requires:       kiwi-systemdeps-filesystems = %{version}-%{release}
Requires:       kiwi-systemdeps-disk-images = %{version}-%{release}
Requires:       kiwi-systemdeps-iso-media = %{version}-%{release}
%if ! 0%{?rhel}
Requires:       kiwi-systemdeps-image-validation = %{version}-%{release}
%endif

%description systemdeps
Host setup helper to pull in all packages required/useful to
leverage all functionality in KIWI.


%package -n python3-%{name}
Summary:        KIWI - Python 3 implementation
# Only require core dependencies, and allow OBS to pull the rest through magic Provides
Requires:       kiwi-systemdeps-core = %{version}-%{release}
# Retain default expectation for local installations
Recommends:     kiwi-systemdeps = %{version}-%{release}
# Enable support for alternative markups
Recommends:     python%{python3_version}dist(anymarkup-core) >= 0.8.0
Recommends:     python%{python3_version}dist(xmltodict) >= 0.12.0

BuildArch:      noarch
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Python 3 library of the KIWI Image System. Provides an operating system
image builder for Linux supported hardware platforms as well as for
virtualization and cloud systems like Xen, KVM, VMware, EC2 and more.

%ifarch %{ix86} x86_64
%package pxeboot
Summary:        KIWI - PXE boot structure
Requires:       syslinux
Requires:       tftp-server

%description pxeboot
This package contains the basic PXE directory structure which is
needed to serve kiwi built images via PXE.
%endif

%package -n dracut-kiwi-lib
Summary:        KIWI - Dracut kiwi Library
Requires:       bc
Requires:       coreutils
Requires:       cryptsetup
Requires:       curl
Requires:       device-mapper
Requires:       dialog
Requires:       dracut
Requires:       e2fsprogs
Requires:       gdisk
Requires:       grep
Requires:       kpartx
Requires:       lvm2
Requires:       mdadm
Requires:       parted
Requires:       pv
Requires:       util-linux
Requires:       xfsprogs
Requires:       xz
BuildArch:      noarch

%description -n dracut-kiwi-lib
This package contains a collection of methods to provide a library
for tasks done in other kiwi dracut modules

%package -n dracut-kiwi-oem-repart
Summary:        KIWI - Dracut module for oem(repart) image type
Requires:       dracut-kiwi-lib = %{version}-%{release}
BuildArch:      noarch

%description -n dracut-kiwi-oem-repart
This package contains the kiwi-repart dracut module which is
used to repartition the oem disk image to the current disk
geometry according to the setup in the kiwi image configuration

%package -n dracut-kiwi-oem-dump
Summary:        KIWI - Dracut module for oem(install) image type
Requires:       dracut-kiwi-lib = %{version}-%{release}
Requires:       gawk
Requires:       kexec-tools
BuildArch:      noarch

%description -n dracut-kiwi-oem-dump
This package contains the kiwi-dump and kiwi-dump-reboot dracut
modules which is used to install an oem image onto a target disk.
It implements a simple installer which allows for user selected
target disk or unattended installation to target. The source of
the image to install could be either from media(CD/DVD/USB) or
from remote.

%package -n dracut-kiwi-live
Summary:        KIWI - Dracut module for iso(live) image type
Requires:       dracut-kiwi-lib = %{version}-%{release}
Requires:       dracut-network
Requires:       device-mapper
Requires:       dialog
Requires:       dracut
Requires:       e2fsprogs
Requires:       util-linux
Requires:       xfsprogs
Requires:       parted
BuildArch:      noarch

%description -n dracut-kiwi-live
This package contains the kiwi-live dracut module which is used
for booting iso(live) images built with KIWI.

%package -n dracut-kiwi-overlay
Summary:        KIWI - Dracut module for vmx(+overlay) image type
Requires:       dracut-kiwi-lib = %{version}-%{release}
Requires:       dracut
Requires:       util-linux
BuildArch:      noarch

%description -n dracut-kiwi-overlay
This package contains the kiwi-overlay dracut module which is used
for booting vmx images built with KIWI and configured to use an
overlay root filesystem.

%package -n dracut-kiwi-verity
Summary:        KIWI - Dracut module for disk with embedded verity metadata
Requires:       dracut-kiwi-lib = %{version}-%{release}
Requires:       dracut

%description -n dracut-kiwi-verity
This package contains the kiwi-verity dracut module which is used
for booting oem images built with KIWI and configured to use an
embedded verity metadata block via the embed_verity_metadata
type attribute.

%package cli
Summary:        Flexible operating system appliance image builder
Provides:       kiwi-schema = 8.2
# So we can reference it by the source package name while permitting this to be noarch
Provides:       %{name} = %{version}-%{release}
Requires:       python3-%{name} = %{version}-%{release}
Requires:       bash-completion
BuildArch:      noarch

%description cli %{desc}


%prep
%autosetup -p1

# Build tends to fail on EL9 without using docopt by itself.
%if ! (0%{?fedora} >= 41 || 0%{?rhel} >= 10)
sed -e 's/docopt-ng.*/docopt = ">=0.6.2"/' -i pyproject.toml
%endif

# Drop shebang for kiwi/xml_parse.py, as we don't intend to use it as an independent script
sed -e "s|#!/usr/bin/env python||" -i kiwi/xml_parse.py


%generate_buildrequires
%pyproject_buildrequires


%build
# Required for some parts
%set_build_flags

%pyproject_wheel

# Build man pages
make -C doc man


%install
# Required for some parts
%set_build_flags

%pyproject_install

# Install man-pages, completion and kiwi default configuration (yes, the slash is needed!)
make buildroot=%{buildroot}/ install

# Install dracut modules (yes, the slash is needed!)
make buildroot=%{buildroot}/ install_dracut

# Get rid of unnecessary doc files
rm -rf %{buildroot}%{_docdir}/packages

# Rename unversioned binaries
mv %{buildroot}%{_bindir}/kiwi-ng %{buildroot}%{_bindir}/kiwi-ng-3

# Create symlinks for correct binaries
ln -sr %{buildroot}%{_bindir}/kiwi-ng %{buildroot}%{_bindir}/kiwi
ln -sr %{buildroot}%{_bindir}/kiwi-ng-3 %{buildroot}%{_bindir}/kiwi-ng

# kiwi pxeboot directory structure to be packed in kiwi-pxeboot
%ifarch %{ix86} x86_64
for i in KIWI pxelinux.cfg image upload boot; do \
    mkdir -p %{buildroot}%{_sharedstatedir}/tftpboot/$i ;\
done
%fdupes %{buildroot}%{_sharedstatedir}/tftpboot
%endif


%post cli
if [ -x /usr/sbin/semanage -a -x /usr/sbin/restorecon ]; then
  semanage fcontext --add --type install_exec_t '%{_bindir}/kiwi'        2> /dev/null || :
  semanage fcontext --add --type install_exec_t '%{_bindir}/kiwi-ng(.*)' 2> /dev/null || :
  restorecon -r %{_bindir}/kiwi %{_bindir}/kiwi-ng* || :
fi

%postun cli
if [ $1 -eq 0 ]; then
  if [ -x /usr/sbin/semanage ]; then
    # file contexts
    semanage fcontext --delete --type install_exec_t '%{_bindir}/kiwi'        2> /dev/null || :
    semanage fcontext --delete --type install_exec_t '%{_bindir}/kiwi-ng(.*)' 2> /dev/null || :
  fi
fi

%files -n python3-%{name}
%license LICENSE
%{_bindir}/kiwi-ng-3*
%{python3_sitelib}/kiwi*/
%dir %{_datadir}/kiwi
%{_datadir}/kiwi/xsl_to_v74/

%files cli
%{_bindir}/kiwi
%{_bindir}/kiwi-ng
%{_datadir}/bash-completion/completions/kiwi-ng
%{_mandir}/man8/kiwi*
%config(noreplace) %{_sysconfdir}/kiwi.yml

%ifarch %{ix86} x86_64
%files pxeboot
%license LICENSE
%{_sharedstatedir}/tftpboot/*
%endif

%files -n dracut-kiwi-lib
%license LICENSE
%{_prefix}/lib/dracut/modules.d/99kiwi-lib/

%files -n dracut-kiwi-oem-repart
%license LICENSE
%{_prefix}/lib/dracut/modules.d/90kiwi-repart/

%files -n dracut-kiwi-oem-dump
%license LICENSE
%{_prefix}/lib/dracut/modules.d/90kiwi-dump/
%{_prefix}/lib/dracut/modules.d/99kiwi-dump-reboot/

%files -n dracut-kiwi-live
%license LICENSE
%{_prefix}/lib/dracut/modules.d/90kiwi-live/

%files -n dracut-kiwi-overlay
%license LICENSE
%{_prefix}/lib/dracut/modules.d/90kiwi-overlay/

%files -n dracut-kiwi-verity
%{_usr}/lib/dracut/modules.d/80kiwi-verity
%{_bindir}/kiwi-parse-verity

%files systemdeps-core
# Empty metapackage

%files systemdeps-bootloaders
# Empty metapackage

%ifnarch ppc64 %{ix86}
%files systemdeps-containers
# Empty metapackage
%endif

%files systemdeps-iso-media
# Empty metapackage

%files systemdeps-filesystems
# Empty metapackage

%files systemdeps-disk-images
# Empty metapackage

%files systemdeps-image-validation
# Empty metapackage

%files systemdeps
# Empty metapackage


%changelog
* Tue May 27 2025 Louis Abel <label@resf.org> - 10.2.24-1
- Rebase to 10.2.24

* Fri May 16 2025 Louis Abel <label@resf.org> - 10.2.22-2
- Rebase to 10.2.22

* Thu May 08 2025 Louis Abel <label@resf.org> - 10.2.20-2
- Rebase to 10.2.20
- Address selinux issues
- Use isomd5sum for tagging ISO's (r10 prep)

* Sun Mar 23 2025 Louis Abel <label@resf.org> - 10.2.13-1
- Rebase to 10.2.13

* Tue Jan 28 2025 Louis Abel <label@resf.org> - 10.2.8-1
- Rebase to 10.2.8

* Thu Dec 12 2024 Louis Abel <label@resf.org> - 10.2.3-1
- Rebase to 10.2.3

* Wed Nov 27 2024 Louis Abel <label@resf.org> - 10.2.2-1
- Rebase to 10.2.2

* Fri Nov 15 2024 Louis Abel <label@resf.org> - 10.1.18-1
- Rebase to 10.1.18

* Sat Aug 24 2024 Neil Hanlon <neil@shrug.pw> - 10.1.2-1
- update to 10.1.2 including various fixes

* Wed Aug 07 2024 Louis Abel <label@resf.org> - 10.1.1-1
- Rebase to 10.1.1

* Fri Jul 12 2024 Louis Abel <label@resf.org> - 10.0.24-1
- Rebase to 10.0.24

* Mon Jun 17 2024 Neil Hanlon <neil@resf.org> - 10.0.21-1
- rebase to 10.0.21
- add "[PATCH] Fixed selinux labels for boot files" from upstream

* Fri May 24 2024 Louis Abel <label@resf.org> - 10.0.16-1.0.5
- Remove patch for testing and reproducing github issue

* Wed May 22 2024 Louis Abel <label@resf.org> - 10.0.16-1.0.3
- Add "rocky" as an EFI vendor default
- Ensure BOOT does not get grub data

* Fri May 03 2024 Louis Abel <label@resf.org> - 10.0.14-1.0.2
- Bump to 10.0.14

* Sat Apr 13 2024 Louis Abel <label@resf.org> - 10.0.11-1.0.2
- Ensure that bootloaders recommends uboot-tools for aarch64
  rather than require it.

* Sat Apr 13 2024 Louis Abel <label@resf.org> - 10.0.11-1.0.1
- Adapt for Rocky Linux
- Remove all EL8, Fedora, Arch, Debian, SuSE references
